##  Before You Start
Analyze your organization's sources of architectural data. Prepare this data for import.
### Required Product
For your initial application portfolio assessment, you need SAP LeanIX Application Portfolio Management, which is the base product.
